==> flutter_nearby_messages_api-0.0.2.tar.gz: ios/Classes/FlutterNearbyMessagesApiPlugin.m <==
#import "FlutterNearbyMessagesApiPlugin.h"
#import "NearbyMessagesApiMCMs.h"

@interface FlutterNearbyMessagesApiPlugin ()
@property(nonatomic, retain) FlutterMethodChannel *channel;
@end

@implementation FlutterNearbyMessagesApiPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel *channel = [FlutterMethodChannel
                                     methodChannelWithName:@"flutter_nearby_messages_api"
                                     binaryMessenger:[registrar messenger]];
    FlutterNearbyMessagesApiPlugin* instance = [[FlutterNearbyMessagesApiPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
    instance.channel = channel;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NearbyMessagesApiMCMs *nearbyMessagesApiMcms = [[NearbyMessagesApiMCMs alloc] initWithChannel:self.channel];
    
    if ([@"publish" isEqualToString:call.method]) {
        NSString* message = call.arguments[@"message"];
        [nearbyMessagesApiMcms publish:message];
        result(@(true));
    } else if ([@"setAPIKey" isEqualToString:call.method]) {
        NSString* key = call.arguments[@"apikey"];
        [nearbyMessagesApiMcms setAPIKey:key];
        result(@(true));
    } else if ([@"unPublish" isEqualToString:call.method]) {
        [nearbyMessagesApiMcms unPublish];
        result(@(true));
    } else if ([@"setGranted" isEqualToString:call.method]) {
        [nearbyMessagesApiMcms setGranted];
        result(@(true));
    } else if ([@"backgroundSubscribe" isEqualToString:call.method]) {
        [nearbyMessagesApiMcms backgroundSubscribe];
        result(@(true));
    } else if ([@"backgroundUnsubscribe" isEqualToString:call.method]) {
        [ nearbyMessagesApiMcms backgroundUnsubscribe];
        result(@(true));
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end

==> flutter_nearby_messages_api-0.0.6.tar.gz: ios/Classes/FlutterNearbyMessagesApiPlugin.m <==
#import "FlutterNearbyMessagesApiPlugin.h"
#import "NearbyMessagesApiMCMs.h"

@interface FlutterNearbyMessagesApiPlugin ()
@property(nonatomic, retain) FlutterMethodChannel *channel;
@end

@implementation FlutterNearbyMessagesApiPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel *channel = [FlutterMethodChannel
                                     methodChannelWithName:@"flutter_nearby_messages_api"
                                     binaryMessenger:[registrar messenger]];
    FlutterNearbyMessagesApiPlugin* instance = [[FlutterNearbyMessagesApiPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
    instance.channel = channel;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NearbyMessagesApiMCMs *nearbyMessagesApiMcms = [[NearbyMessagesApiMCMs alloc] initWithChannel:self.channel];
    
    if ([@"publish" isEqualToString:call.method]) {
        NSString* message = call.arguments[@"message"];
        [nearbyMessagesApiMcms publish:message];
        result(@(true));
    } else if ([@"setAPIKey" isEqualToString:call.method]) {
        NSString* key = call.arguments[@"apikey"];
        [nearbyMessagesApiMcms setAPIKey:key];
        result(@(true));
    } else if ([@"unPublish" isEqualToString:call.method]) {
        [nearbyMessagesApiMcms unPublish];
        result(@(true));
    } else if ([@"setPermissionAlert" isEqualToString:call.method]) {
        NSString* title = call.arguments[@"title_text"];
        NSString* message = call.arguments[@"message_text"];
        NSString* deny = call.arguments[@"deny_text"];
        NSString* grant = call.arguments[@"grant_text"];
        [nearbyMessagesApiMcms setPermissionAlert:title :message :deny :grant];
        result(@(true));
    } else if ([@"backgroundSubscribe" isEqualToString:call.method]) {
        [nearbyMessagesApiMcms backgroundSubscribe];
        result(@(true));
    } else if ([@"backgroundUnsubscribe" isEqualToString:call.method]) {
        [nearbyMessagesApiMcms backgroundUnsubscribe];
        result(@(true));
    } else if ([@"setNearbyAccessPermission" isEqualToString:call.method]) {
        BOOL value = call.arguments[@"value"];
        [nearbyMessagesApiMcms setNearbyAccessPermission:value];
        result(@(true));
    } else {
        result(FlutterMethodNotImplemented);
    }
}

@end
